@@ -13,7 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import urlparse
+from six.moves.urllib import parse as urlparse
 
 from keystoneclient.tests import fakes
 from keystoneclient.tests.v2_0 import utils
